@@ -56,8 +56,11 @@ def print_fl(fromlist: list, file=sys.stdout):
     *This function is deprecated, and may be removed
     at the next major patch.*
     """
-    warnings.warn('Original syntax, may be removed at next major patch. '
-                  'Use fromlist.print() instead.', DeprecationWarning)
+    warnings.warn(
+        "Original syntax, may be removed at next major patch. "
+        "Use fromlist.print() instead.",
+        DeprecationWarning,
+    )
     print(fromlist, file)
 
 
@@ -78,8 +81,7 @@ def make(fromlist: list, pathlike=None) -> Path:
     However, using the :class:`.fromlist.temp()` context manager might
     be even more handy.
     """
-    filelike = None
-    mode = 'wt'
+    mode = "wt"
     if pathlike is None:
         filelike = tempfile.NamedTemporaryFile(mode=mode, delete=False)
     else:
@@ -91,7 +93,7 @@ def make(fromlist: list, pathlike=None) -> Path:
     return Path(filelike.name)
 
 
-class open_fl():
+class open_fl:
     """This is a context manager that works similarly to :func:`open`, but
     for creating fromlist files.  Use it like this::
 
@@ -103,8 +105,12 @@ class open_fl():
     *This context manager is deprecated, and may be removed
     at the next major patch.*
     """
-    warnings.warn("Original syntax, may be removed at next major patch. "
-                  "Use fromlist.temp() instead.", DeprecationWarning)
+
+    warnings.warn(
+        "Original syntax, may be removed at next major patch. "
+        "Use fromlist.temp() instead.",
+        DeprecationWarning,
+    )
 
     def __init__(self, fromlist: list, pathlike=None):
         self.fromlist = fromlist
@@ -117,7 +123,7 @@ class open_fl():
 
     def __enter__(self):
         p = make(self.fromlist, self.name)
-        self.file = open(p, mode='r')
+        self.file = open(p, mode="r")
         return self.file
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -127,7 +133,7 @@ class open_fl():
             os.unlink(self.file.name)
 
 
-class temp():
+class temp:
     """This is a context manager that creates a temporary
     fromlist file and then gets rid of it for you.
     Use it like this::
